summaryrefslogtreecommitdiff
path: root/src/SMAPI/Framework/Events/ModEvents.cs
diff options
context:
space:
mode:
Diffstat (limited to 'src/SMAPI/Framework/Events/ModEvents.cs')
-rw-r--r--src/SMAPI/Framework/Events/ModEvents.cs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/SMAPI/Framework/Events/ModEvents.cs b/src/SMAPI/Framework/Events/ModEvents.cs
index 8ad3936c..1d1c92c6 100644
--- a/src/SMAPI/Framework/Events/ModEvents.cs
+++ b/src/SMAPI/Framework/Events/ModEvents.cs
@@ -26,8 +26,8 @@ namespace StardewModdingAPI.Framework.Events
/// <summary>Events raised when something changes in the world.</summary>
public IWorldEvents World { get; }
- /// <summary>Events serving specialised edge cases that shouldn't be used by most mods.</summary>
- public ISpecialisedEvents Specialised { get; }
+ /// <summary>Events serving specialized edge cases that shouldn't be used by most mods.</summary>
+ public ISpecializedEvents Specialized { get; }
/*********
@@ -44,7 +44,7 @@ namespace StardewModdingAPI.Framework.Events
this.Multiplayer = new ModMultiplayerEvents(mod, eventManager);
this.Player = new ModPlayerEvents(mod, eventManager);
this.World = new ModWorldEvents(mod, eventManager);
- this.Specialised = new ModSpecialisedEvents(mod, eventManager);
+ this.Specialized = new ModSpecializedEvents(mod, eventManager);
}
}
}